@@ -72,8 +72,7 @@ class ExportAttributes:
         :param quoting: Puts quotes around cells that contain the separator character.
         :param escapechar: Escapes the separator character.
         :param validate: Whether to make sure that input parameters are valid.
-        :param kwargs: Any parameter supported by ``pandas.DataFrame.to_csv()`` can be passed
-            (see `their documentation <https://pandas.pydata.org/pandas-docs/stable/reference/api/pandas.DataFrame.to_csv.html>`__).
+        :param kwargs: Any parameter supported by :meth:`pandas:pandas.DataFrame.to_csv` can be passed.
         """
         if validate:
             # Check that directory exists
@@ -116,7 +115,7 @@ class CrawlingAttributes:
 
                  validate: bool = True
                  ):
-        """Specify how to conduct the crawling, e. g. how to filter irrelevant URLs or limits on the number of URLs crawled.
+        """Specify how to conduct the crawling, including filtering irrelevant URLs or limiting the number of crawled URLs.
 
         :param filter_non_standard_schemes: Filter URLs starting with schemes other than ``http:`` or ``https:`` (e.g., ``mailto:`` or ``javascript:``).
         :param filter_media_files: Whether to filter media files. Recommended: ``True`` to avoid long runtimes caused by large file downloads.
