@@ -13,18 +13,33 @@ class Website(BeautifulSoup):
         :param url: Website URL.
         :param steps_from_start_page: Specifies number of steps from start URL to reach the given URL.
             Note that this is an optional parameter used in conjunction with the Crawler object.
+
         :raises: Exceptions raised during URL parsing.
         """
+        #: Website URL.
         self.url = url
-        self.parsed_url = ParsedUrl(self.url)    # this will raise an error if the URL is invalid
 
+        #: :class:`.ParsedUrl` object for accessing the various URL parts (hostname, domain, path, ...).
+        self.parsed_url = ParsedUrl(self.url)
+
+        #: Number of steps from start URL to reach the URL in crawlings.
+        #: This has to be passed during object initialization, which is done automatically in
+        #: :func:`~scrawler.backends.multithreading_backend.crawl_domain` and :func:`~scrawler.backends.asyncio_backend.async_crawl_domain`.
         self.steps_from_start_page = steps_from_start_page
 
+        #: Website's HTML text as a string. Only available after retrieving the Website using :func:`fetch` or :func:`fetch_async`.
+        self.html_text = None
+
+        #: HTTP response as :class:`requests:requests.Response` or :class:`aiohttp:aiohttp.ClientResponse`
+        #: (depending on whether the website was fetched with :func:`fetch` or :func:`fetch_async`).
+        #: Only available after retrieving the Website using :func:`fetch` or :func:`fetch_async`.
+        self.http_response = None
+
     def fetch(self, **kwargs):
         """Fetch website from given URL and construct ``BeautifulSoup`` from response data.
 
         :param kwargs: Are passed on to :func:`.get_html`.
-        :raises: Exceptions from making the request (requests library) and HTML parsing.
+        :raises: Exceptions from making the request (using :func:`requests:requests.get`) and HTML parsing.
         :return: Website object with ``BeautifulSoup`` properties.
         """
         self.html_text, self.http_response = get_html(self.url, return_response_object=True, **kwargs)
@@ -37,9 +52,9 @@ class Website(BeautifulSoup):
     async def fetch_async(self, session: aiohttp.ClientSession, **kwargs):
         """Asynchronously fetch website from given URL and construct BeautifulSoup from response data.
 
-        :param session: `aiohttp.ClientSession <https://docs.aiohttp.org/en/v3.7.3/client_reference.html#aiohttp.ClientSession>`__ to be used for making the request asynchronously.
+        :param session: :class:`aiohttp:aiohttp.ClientSession` to be used for making the request asynchronously.
         :param kwargs: Are passed on to :func:`.async_get_html`.
-        :raises: Exceptions from making the request (using `aiohttp <https://docs.aiohttp.org/en/stable/>`__) and HTML parsing.
+        :raises: Exceptions from making the request (using :meth:`aiohttp:aiohttp.ClientSession.get`) and HTML parsing.
         :return: Website object with ``BeautifulSoup`` properties.
         """
         self.html_text, self.http_response = await async_get_html(self.url, session=session,
